@@ -3,7 +3,9 @@
 
 
 def colors(color):
-    '''Print colors'''
+    '''
+    Paint text with following colors
+    '''
 
     paint = {
         'black'      : '\x1b[30m',
