@@ -35,90 +35,88 @@ from .files import *
 
 __prog__ = 'pysed'
 __author__ = 'dslackw'
-__version_info__ = (0, 3, 0)
+__version_info__ = (0, 3, 1)
 __version__ = '{0}.{1}.{2}'.format(*__version_info__)
 __license__ = 'GNU General Public License v3 (GPLv3)'
 __email__ = 'd.zlatanidis@gmail.com'
 
 
 def replace(read, arg2, arg3):
-    '''Replace characters or entire text with another.
-        Chose specific areas and to replace
-        yet Add color to text'''
+    '''
+    Replace characters or entire text with another.
+    Chose specific areas and to replace
+    yet Add color to text
+    '''
 
-    OPTIONS_1 = get_to(arg2, '/')
-    arg2 = arg2.replace(OPTIONS_1 + '/', '', 1)
-    OPTIONS_2 = get_upside(arg3, '/')
-    arg3 = arg3.replace('/' + OPTIONS_2, '', 1)
+    opt_LEFT = get_to(arg2, '/')
+    arg2 = arg2.replace(opt_LEFT + '/', '', 1)
+
+    opt_RIGHT = get_upside(arg3, '/')
+    arg3 = arg3.replace('/' + opt_RIGHT, '', 1)
 
     find_text = findall(arg2, read)
 
-    nums = get_nums(OPTIONS_1)
-    OPTIONS_1 = OPTIONS_1.replace(nums, '')
+    nums = get_nums(opt_LEFT)
+    opt_LEFT = opt_LEFT.replace(nums, '')
 
     if nums == '':
         nums = 0
 
-    if OPTIONS_2 in ['black', 'red', 'green', 'yellow', 'cyan', 'blue', 'magenta']:
-        color = colors(OPTIONS_2)
+    if opt_RIGHT in ['black', 'red', 'green', 'yellow',
+                     'cyan', 'blue', 'magenta']:
+        color = colors(opt_RIGHT)
         default = colors('default')
     else:
         color = ''
         default = ''
 
-    if OPTIONS_1.startswith('s='):
-        nums_all = OPTIONS_1.replace('s=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    if opt_LEFT.startswith('s='):
+        nums_all = opt_LEFT.replace('s=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = select(read, nums_all)
         find_text = findall(arg2, region)
-    elif OPTIONS_1.startswith('select='):
-        nums_all = OPTIONS_1.replace('select=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    elif opt_LEFT.startswith('select='):
+        nums_all = opt_LEFT.replace('select=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = select(read, nums_all)
         find_text = findall(arg2, region)
 
-    if OPTIONS_1.startswith('n='):
-        nums_all = OPTIONS_1.replace('n=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    if opt_LEFT.startswith('n='):
+        nums_all = opt_LEFT.replace('n=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = lines(read, nums_all)
         find_text = findall(arg2, region)
-    elif OPTIONS_1.startswith('lines='):
-        nums_all = OPTIONS_1.replace('lines=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    elif opt_LEFT.startswith('lines='):
+        nums_all = opt_LEFT.replace('lines=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = lines(read, nums_all)
         find_text = findall(arg2, region)
 
     result = read
     find_text = set(find_text)
+
     for text in find_text:
-        if OPTIONS_1 == 'm=' or OPTIONS_1 == 'max=':
+        if opt_LEFT == 'm=' or opt_LEFT == 'max=':
             result = read.replace(text, color + arg3 + default,
                                   int(nums))
-
-        elif OPTIONS_1 == 'u' or OPTIONS_1 == 'upper':
+        elif opt_LEFT == 'u' or opt_LEFT == 'upper':
             result = read.replace(text,
                                   color + arg3.upper() + default)
-
-        elif OPTIONS_1 == 'u=*' or OPTIONS_1 == 'upper=*':
+        elif opt_LEFT == 'u=*' or opt_LEFT == 'upper=*':
             result = color + read.upper() + default
-
-        elif OPTIONS_1 == 'l' or OPTIONS_1 == 'lower':
+        elif opt_LEFT == 'l' or opt_LEFT == 'lower':
             result = read.replace(text,
                                   color + arg3.lower() + default)
-
-        elif OPTIONS_1 == 'l=*' or OPTIONS_1 == 'lower=*':
+        elif opt_LEFT == 'l=*' or opt_LEFT == 'lower=*':
             result = color + read.lower() + default
-
-        elif OPTIONS_1 == 's=' or OPTIONS_1 == 'select=':
+        elif opt_LEFT == 's=' or opt_LEFT == 'select=':
             region_original = region
             region = region.replace(text, color + arg3 + default)
             result = result.replace(region_original, region)
-
-        elif OPTIONS_1 == 'n=' or OPTIONS_1 == 'lines=':
+        elif opt_LEFT == 'n=' or opt_LEFT == 'lines=':
             region_original = region
             region = region.replace(text, color + arg3 + default)
-            result = result.replace(region_original, region)            
-
+            result = result.replace(region_original, region)
         else:
             result = result.replace(text, color + arg3 + default)
 
@@ -126,91 +124,96 @@ def replace(read, arg2, arg3):
 
 
 def append(read, arg2, arg3):
-    '''Introduce new characters or the entire text
-        with new and can also add color. As with the
-        replacement options and you can select specific
-         areas'''
+    '''
+    Introduce new characters or the entire text
+    with new and can also add color. As with the
+    replacement options and you can select specific
+    areas
+    '''
 
-    OPTIONS_1 = get_to(arg2, '/')
-    arg2 = arg2.replace(OPTIONS_1 + '/', '', 1)
-    OPTIONS_2 = get_upside(arg3, '/')
-    arg3 = arg3.replace('/' + OPTIONS_2, '', 1)
+    opt_LEFT = get_to(arg2, '/')
+    arg2 = arg2.replace(opt_LEFT + '/', '', 1)
+
+    opt_RIGHT = get_upside(arg3, '/')
+    arg3 = arg3.replace('/' + opt_RIGHT, '', 1)
 
     find_text = findall(arg2, read)
 
-    nums = get_nums(OPTIONS_1)
-    OPTIONS_1 = OPTIONS_1.replace(nums, '')
+    nums = get_nums(opt_LEFT)
+    opt_LEFT = opt_LEFT.replace(nums, '')
 
     if nums == '':
         nums = 0
 
-    if OPTIONS_2 in ['black', 'red', 'green', 'yellow', 'cyan', 'blue', 'magenta']:
-        color = colors(OPTIONS_2)
+    if opt_RIGHT in ['black', 'red', 'green', 'yellow',
+                    'cyan', 'blue', 'magenta']:
+        color = colors(opt_RIGHT)
         default = colors('default')
     else:
         color = ''
         default = ''
 
-    if OPTIONS_1.startswith('s='):
-        nums_all = OPTIONS_1.replace('s=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    if opt_LEFT.startswith('s='):
+        nums_all = opt_LEFT.replace('s=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = select(read, nums_all)
         find_text = findall(arg2, region)
-    elif OPTIONS_1.startswith('select='):
-        nums_all = OPTIONS_1.replace('select=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    elif opt_LEFT.startswith('select='):
+        nums_all = opt_LEFT.replace('select=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = select(read, nums_all)
         find_text = findall(arg2, region)
 
-    if OPTIONS_1.startswith('n='):
-        nums_all = OPTIONS_1.replace('n=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    if opt_LEFT.startswith('n='):
+        nums_all = opt_LEFT.replace('n=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = lines(read, nums_all)
         find_text = findall(arg2, region)
-    elif OPTIONS_1.startswith('lines='):
-        nums_all = OPTIONS_1.replace('lines=', '')
-        OPTIONS_1 = OPTIONS_1.replace(nums_all, '')
+    elif opt_LEFT.startswith('lines='):
+        nums_all = opt_LEFT.replace('lines=', '')
+        opt_LEFT = opt_LEFT.replace(nums_all, '')
         region = lines(read, nums_all)
         find_text = findall(arg2, region)
 
     result = read
     find_text = set(find_text)
+
     for text in find_text:
-        if OPTIONS_1 == 'm=' or OPTIONS_1 == 'max=':
+        if opt_LEFT == 'm=' or opt_LEFT == 'max=':
             result = read.replace(text,
                                   color + arg3 + default + text,
                                   int(nums))
-
-        elif OPTIONS_1 == 's=' or OPTIONS_1 == 'select=':
+        elif opt_LEFT == 's=' or opt_LEFT == 'select=':
             region_original = region
             region = region.replace(text,
                                     color + arg3 + default + text)
             result = result.replace(region_original, region)
-
-        elif OPTIONS_1 == 'n=' or OPTIONS_1 == 'lines=':
+        elif opt_LEFT == 'n=' or opt_LEFT == 'lines=':
             region_original = region
-            region = region.replace(text, 
+            region = region.replace(text,
                                     color + arg3 + default + text)
             result = result.replace(region_original, region)
-
         else:
             result = result.replace(text,
                                    color + arg3 + default + text)
+
     return result.rstrip()
 
 
 def lines(read, argX):
-    '''Print all lines of text or specific.
-        Printing lines with a step'''
+    '''
+    Print all lines of text or specific.
+    Printing lines with a step
+    '''
 
     result = []
     results = []
 
-    OPTIONS_1 = get_to(argX, '/')
-    argX = argX.replace(OPTIONS_1 + '/', '', 1)
+    opt_LEFT = get_to(argX, '/')
+    argX = argX.replace(opt_LEFT + '/', '', 1)
 
-    step = get_nums(OPTIONS_1)
-    OPTIONS_1 = OPTIONS_1.replace(step, '')
+    step = get_nums(opt_LEFT)
+    opt_LEFT = opt_LEFT.replace(step, '')
 
     if step == '' or step == "0":
         step = 1
@@ -218,81 +221,66 @@ def lines(read, argX):
     for line in read.splitlines():
         result.append(line)
 
-    if argX == '*' or argX == 'all':
-        if OPTIONS_1 == 'step=' or OPTIONS_1 == 's=':
-            for line in range(0, len(result), int(step)):
-                results.append(result[line])
-            result = results
-        else:
-            result = read,
-
-    elif argX.startswith('[') and argX.endswith(']'):
-        argX = argX.replace('[', '', 1)
-        argX = argX.replace(']', '', 1)
-
-        line_nums = argX.replace('-', '\n').split()
-
-        try:
+    try:
+        if argX == '*' or argX == 'all':
+            if opt_LEFT == 'step=' or opt_LEFT == 's=':
+                for line in range(0, len(result), int(step)):
+                    results.append(result[line])
+                result = results
+            else:
+                result = read,
+        elif argX.startswith('[') and argX.endswith(']'):
+            argX = argX.replace('[', '', 1)
+            argX = argX.replace(']', '', 1)
+            line_nums = argX.replace('-', '\n').split()
             if len(line_nums) < 2 or int(
-                    line_nums[1]) >= len(result):
+                   line_nums[1]) >= len(result):
                 pass
-
             else:
-
                 for n in range(int(line_nums[0]),
                                int(line_nums[1]) + 1):
                     results.append(result[int(n)])
                 result = results
-
-        except ValueError:
-            pass
-
-    elif OPTIONS_1 == 'c' or OPTIONS_1 == 'count':
-        i = 0
-        for line in read.splitlines():
-            results.append('{0} <-- {1}'.format(i, line))
-            i += 1        
-        result = results
-
-    else:
-
-        try:
+        elif opt_LEFT == 'c' or opt_LEFT == 'count':
+            i = 0
+            for line in read.splitlines():
+                results.append('{0} <-- {1}'.format(i, line))
+                i += 1
+            result = results
+        else:
             line_nums = argX.replace(',', '\n').split()
-
             for num in line_nums:
                 if int(num) >= len(result):
                     pass
                 else:
                     results.append(result[int(num)])
             result = results
-
-        except ValueError:
+    except ValueError:
             pass
 
     return '\n'.join(result).rstrip()
 
 
 def cat(file, arg0, arg1, arg2, arg3):
-    '''Print all results before any changes save in a file
-        or print statics or extract chars'''
+    '''
+    Print all results before any changes save in a file
+    or print statics or extract chars
+    '''
 
     result = []
 
     try:
-
         read = open_file_for_read(file)
 
         arg_lines = arg1
-        OPTIONS_1 = get_to(arg1, '/')
-        arg1 = arg1.replace(OPTIONS_1 + '/', '', 1)
+        opt_LEFT = get_to(arg1, '/')
+
+        arg1 = arg1.replace(opt_LEFT + '/', '', 1)
         find_text = findall(arg1, read)
 
         if arg0 == '-p' or arg0 == '--print':
-
             pass
-
-            if OPTIONS_1 == 's' or OPTIONS_1 == 'sum':
-
+            if opt_LEFT == 's' or opt_LEFT == 'sum':
                 words = read.split()
                 chars = ''.join(words)
                 for line in range(len(read.splitlines())):
@@ -301,42 +289,33 @@ def cat(file, arg0, arg1, arg2, arg3):
                 print ('%d characters' % len(chars))
                 print ('%d words' % len(words))
                 print ('%d blanks' % (len(read) - len(chars)))
-
-            elif OPTIONS_1 == 'c' or OPTIONS_1 == 'chars':
-
+            elif opt_LEFT == 'c' or opt_LEFT == 'chars':
                 print ('find %d --> \'%s\'' % (
                     len(find_text), arg1))
-
-            elif OPTIONS_1 == 'e' or OPTIONS_1 == 'extract':
-
+            elif opt_LEFT == 'e' or opt_LEFT == 'extract':
                 print (' '.join(find_text))
-
             else:
-
                 print ('{}'.format(read,).strip())
-
         elif arg0 == '-l' or arg0 == '--lines':
             result = lines(read, arg_lines)
-
         elif arg0 == '-r' or arg0 == '--replace':
             result = replace(read, arg2, arg3)
 
         elif arg0 == '-i' or arg0 == '--insert':
             result = append(read, arg2, arg3)
-
         else:
             arguments_error(arg0, '')
-
         if result != []:
             print ('{}'.format(result,))
-
     except IOError:
         print ("%s: can't read %s: No such file or directory"
                % (__prog__, file))
 
 
 def write_replace_text(file, arg1, arg2):
-    '''Replace the text and save changes to the file'''
+    '''
+    Replace the text and save changes to the file
+    '''
 
     result = []
 
@@ -344,36 +323,35 @@ def write_replace_text(file, arg1, arg2):
         file = open_file_for_read_and_write(file)
         read = file.read()
         result = replace(read, arg1, arg2)
-
         if result != []:
             write_to_file(file, result)
-
     except IOError:
         print ("%s: can't read %s: No such file or directory"
                % (__prog__, file))
 
 
 def write_append_text(file, arg1, arg2):
-    '''Insert text and save changes to the file'''
+    '''
+    Insert text and save changes to the file
+    '''
 
     result = []
 
     try:
-
         file = open_file_for_read_and_write(file)
         read = file.read()
         result = append(read, arg1, arg2)
-
         if result != []:
             write_to_file(file, result)
-
     except IOError:
         print ("%s: can't read %s: No such file or directory"
                % (__prog__, file))
 
 
 def version():
-    '''Print version, license and email'''
+    '''
+    Print version, license and email
+    '''
 
     print ('version : {}'.format(__version__))
     print ('License : {}'.format(__license__))
@@ -381,7 +359,9 @@ def version():
 
 
 def arguments_view():
-    '''Print arguments options'''
+    '''
+    Print arguments options
+    '''
 
     print ('usage: pysed [-h] [-v] [-p] [-l] [-r] [-i]\n')
     print ('Utility that parses and transforms text\n')
@@ -404,84 +384,70 @@ def arguments_view():
 
 
 def arguments_error(arg0, argx):
-    '''Print errors arguments'''
+    '''
+    Print errors arguments
+    '''
 
     print ('usage: %s [-h] [-v] [-p] [-l] [-r] [-i]\n' % __prog__)
 
     if arg0 == '':
         print ('%s: error: argument: expected one argument' % __prog__)
-
     elif arg0 in ['-p', '--print',
                   '-l', '--lines',
                   '-r', '--replace',
                   '-i', '--insert']:
         print ('%s: argument %s: expected at least one argument'
                % (__prog__, arg0))
-
     else:
         print ('%s: error: unrecognized arguments: %s %s'
                % (__prog__, arg0, ' '.join(argx)))
 
 
 def main():
-
     arg = sys.argv
     arg.pop(0)
 
     if len(arg) == 2:
         file = arg[1]
-
     elif len(arg) == 3:
         file = arg[2]
-
     elif len(arg) == 4:
         file = arg[3]
-
     elif len(arg) == 5:
         file = arg[4]
 
     if len(arg) == 0:
         arguments_error('', '')
-
     elif (len(arg) == 1 and arg[0] == '-h' or len(arg) == 1
-          and arg[0] == '--help'):
+                        and arg[0] == '--help'):
         arguments_view()
-
-    elif (len(arg) == 1 and arg[0] == '-v' or len(arg) == 1 and
-          arg[0] == '--version'):
+    elif (len(arg) == 1 and arg[0] == '-v' or len(arg) == 1 
+                        and arg[0] == '--version'):
         version()
-
-    elif (len(arg) == 2 and arg[0] == '-p' or len(arg) == 2 and
-          arg[0] == '--print'):
+    elif (len(arg) == 2 and arg[0] == '-p' or len(arg) == 2 
+                        and arg[0] == '--print'):
         cat(file, arg[0], '', '', '')
-
-    elif (len(arg) == 3 and arg[0] == '-p' or len(arg) == 3 and
-          arg[0] == '--print'):
+    elif (len(arg) == 3 and arg[0] == '-p' or len(arg) == 3
+                        and arg[0] == '--print'):
         cat(file, arg[0], arg[1], '', '')
-
-    elif (len(arg) == 5 and arg[1] == '-p' or len(arg) == 5 and
-          arg[1] == '--print'):
+    elif (len(arg) == 5 and arg[1] == '-p' or len(arg) == 5
+                        and arg[1] == '--print'):
         cat(file, arg[0], arg[1], arg[2], arg[3])
-
-    elif (len(arg) == 3 and arg[0] == '-l' or len(arg) == 3 and
-          arg[0] == '--lines'):
+    elif (len(arg) == 3 and arg[0] == '-l' or len(arg) == 3
+                        and arg[0] == '--lines'):
         cat(file, arg[0], arg[1], '', '')
-
-    elif (len(arg) == 4 and arg[0] == '-r' or len(arg) == 4 and
-          arg[0] == '--replace'):
+    elif (len(arg) == 4 and arg[0] == '-r' or len(arg) == 4
+                        and arg[0] == '--replace'):
         write_replace_text(file, arg[1], arg[2])
-
-    elif (len(arg) == 4 and arg[0] == '-i' or len(arg) == 4 and
-          arg[0] == '--insert'):
+    elif (len(arg) == 4 and arg[0] == '-i' or len(arg) == 4
+                        and arg[0] == '--insert'):
         write_append_text(file, arg[1], arg[2])
-
     elif not any(
-            [len(arg) == 1 and arg[0] == '-p', len(arg) == 1 and arg[0] == '--print',
-             len(arg) == 1 and arg[0] == '-l', len(arg) == 1 and arg[0] == '--lines',
-             len(arg) == 1 and arg[0] == '-r', len(arg) == 1 and arg[0] == '--replace',
-             len(arg) == 1 and arg[0] == '-i', len(arg) == 1 and arg[0] == '--insert', ]):
+        [len(arg) == 1 and arg[0] == '-p', len(arg) == 1 and arg[0] == '--print',
+         len(arg) == 1 and arg[0] == '-l', len(arg) == 1 and arg[0] == '--lines',
+         len(arg) == 1 and arg[0] == '-r', len(arg) == 1 and arg[0] == '--replace',
+         len(arg) == 1 and arg[0] == '-i', len(arg) == 1 and arg[0] == '--insert', ]):
         arguments_error(arg[0], arg[1:])
-
     else:
         arguments_error(arg[0], arg[1:])
 
